Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func LevelNames ¶
func LevelNames() string
LevelNames returns a comma separated list of available levels.
func SetupGlobalLogger ¶
SetupGlobalLogger uses to provided log level string and applies it globally.
Types ¶
type FileNameHook ¶
type FileNameHook struct {
Formatter func(file, function string, line int) string
// contains filtered or unexported fields
}
func NewFilenameHook ¶
func NewFilenameHook() *FileNameHook
NewFilenameHook creates a new default FileNameHook.
func (*FileNameHook) Fire ¶
func (f *FileNameHook) Fire(entry *logrus.Entry) error
Fire executes the hook for every logrus entry.
func (*FileNameHook) Levels ¶
func (f *FileNameHook) Levels() []logrus.Level
Levels returns the levels for which the hook is activated. This contains currently only the DebugLevel.
type StepLogger ¶
StepLogger is a step counting logger implementation.
func (*StepLogger) WithStep ¶
func (l *StepLogger) WithStep() *logrus.Entry
WithStep increments the internal step counter and adds the output to the field.
Click to show internal directories.
Click to hide internal directories.